<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\MAN\Services\FileUploaderService;
use Teknisa\MAN\Services\ParamKDSService;
use Teknisa\MAN\Services\NovoCodigo;
use Zeedhi\Framework\DTO\Response\Message;
use Teknisa\MAN\Utilities;
use \Util\Exception;

class ParamKDS extends  \Teknisa\MAN\Controllers\TeknisaCrud {

    const dataSourceTeclas         = 'vnd09700_kds_teclas',
          dataSourceCores          = 'vnd09700_kds_cores',
          dataSourceSetor          = 'vnd09700_kds_setor',
          dataSourceFilial         = 'vnd09700_kds_filial',
          dataSourceSetorFilial    = 'vnd09700_kds_setor_filial',
          dataSourceArquivos       = 'selectArquivos',
          dataSourceSetorLoja      = 'vnd09700_kds_setor_loja',
          dataSourceProdutoSetor   = 'vnd09700_kds_produtos_setor',
          dataSourceProdObsSetor   = 'vnd09700_kds_prodobs_setor',
          dataSourceIntervalo      = 'vnd09700_kds_intervalos',
          dataSourceAltAutom       = 'vnd09700_kds_produtos_setor_editAut',
          dataSourceLinhaProducao  = 'vnd09700_kds_linhaprod',
          dataSourceLinhaProducaoSetor  = 'vnd09700_kds_linhaprod_setor',
          dataSourceOrdem          = 'vnd09700_kds_ordem_mod',
          dataSourceLinhaPrincipal = 'vnd09700_kds_linha_principal',
          dataSourceFindSetorLoja  = 'vnd09700_kds_setores_loja_disponiveis';

    protected $ParamKDSService,
              $fileUploaderService,
              $novoCodigo,
              $conn,
              $utilService;

    protected $parameterBagColumnsDefault = array('CDSETOR', 'CDFILIAL', 'CDPRODUTO'),
              $parameterBagColumnsSetorLoja = array('CDLOJA', 'CDFILIAL'),
              $parameterBagColmnsIntervalo = array('CDSETOR','CDPRODUTO', 'NRSEQINTERVALO'),
              $parameterBagColumnsLinhaProd = array('CDFILIAL'),
              $parameterBagColumnsLinhaProdSetor = array('CDFILIAL', 'CDLINHAPROD'),
              $parameterBagColumnsLinhaPrincipal = array('CDFILIAL'),
              $parameterBagColumnsOrdem = array('CDFILIAL'),
              $parameterBagColmnsUnidadeKDS = array('CDFILIAL', 'NRATRAPADRAO');

    public function __construct ($crudService, $parameterBag, ParamKDSService $ParamKDSService, Manager $dataSourceManager, FileUploaderService $fileUploaderService, NovoCodigo $novoCodigo, $conn, Utilities\Util $utilService) {
        $this->crudService              = $crudService;
        $this->parameterBag             = $parameterBag;
        $this->ParamKDSService          = $ParamKDSService;
        $this->dataSourceManager        = $dataSourceManager;
        $this->fileUploaderService      = $fileUploaderService;
        $this->novoCodigo               = $novoCodigo;
        $this->conn                     = $conn;
        $this->utilService              = $utilService;
    }

    public function findSetorPorLoja(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceFindSetorLoja;
        $this->parameterBagColumns = array('CDFILIAL', 'CDLOJA');
        parent::find($request, $response);
    }

    public function findIntervalos(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceIntervalo;
        $this->parameterBagColumns = $this->parameterBagColmnsIntervalo;
        parent::find($request, $response);
    }

    public function deleteIntervalos(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceIntervalo;
        parent::delete($request, $response);
    }

    public function saveIntervalos(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceIntervalo;
        $this->parameterBagColumns = $this->parameterBagColmnsIntervalo;
        parent::save($request, $response);
    }

    public function findTeclas(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceTeclas;
        $this->parameterBagColumns = $this->parameterBagColumnsDefault;
        parent::find($request, $response);
    }

    public function findCores(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceCores;
        $this->parameterBagColumns = $this->parameterBagColumnsDefault;
        parent::find($request, $response);
    }

    public function findSetor(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceSetor;
        $this->parameterBagColumns = $this->parameterBagColumnsDefault;
        parent::find($request, $response);
    }

    public function findSetorFilial(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceSetorFilial;
        $this->parameterBagColumns = $this->parameterBagColumnsDefault;
        parent::find($request, $response);
    }

    public function findSetorLoja(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceSetorLoja;
        $this->parameterBagColumns = $this->parameterBagColumnsSetorLoja;
        parent::find($request, $response);
    }

    public function findLinhaProd(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceLinhaProducao;
        $this->parameterBagColumns = $this->parameterBagColumnsLinhaProd;
        parent::find($request, $response);
    }

    public function findLinhaProdSetor(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceLinhaProducaoSetor;
        $this->parameterBagColumns = $this->parameterBagColumnsLinhaProdSetor;
        parent::find($request, $response);
    }

     public function findOrdemMod(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceOrdem;
        $this->parameterBagColumns = $this->parameterBagColumnsOrdem;
        parent::find($request, $response);
    }

    public function findLinhaPrincipal(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceLinhaPrincipal;
        $this->parameterBagColumns = $this->parameterBagColumnsLinhaPrincipal;
        parent::find($request, $response);
    }

    public function findProdutoSetor(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceProdutoSetor;
        $this->parameterBagColumns =$this->parameterBagColumnsDefault;

        $newResponse = new DTO\Response();
        parent::find($request, $newResponse);

        if(empty($newResponse->getDataSets())) {
            $rows = [];
        } else {
            $rows = $newResponse->getDataSets()[0]->getRows();
        }

        for($i = 0; $i < count($rows); $i++) {
            $rows[$i] = $this->returnTimeConcat($rows[$i], 'NRTEMPOPROD');
            $rows[$i] = $this->returnTimeConcat($rows[$i], 'NRTEMPOEXIB');
        }

        $response->addDataSet(new DataSet(self::dataSourceProdutoSetor, $rows));
    }

    private function returnTimeConcat ($row, $name) {
        if($row[$name] >= 60) {
            $row[$name.'MIN'] = intVal(trim($row[$name]) / 60);
            $row[$name.'SEC'] = (trim($row[$name]) % 60);
        } else {
            $row[$name.'MIN'] = 0;
            $row[$name.'SEC'] = trim($row[$name]);
        }
        $row[$name.'CONCAT'] = str_pad($row[$name.'MIN'], 2, "0", STR_PAD_LEFT).':'.str_pad($row[$name.'SEC'], 2, "0", STR_PAD_LEFT);
        $row[$name]         =  str_pad($row[$name.'MIN'], 2, "0", STR_PAD_LEFT).':'.str_pad($row[$name.'SEC'], 2, "0", STR_PAD_LEFT);
        return $row;
    }

    public function findProdObsSetor(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceProdObsSetor;
        $this->parameterBagColumns = $this->parameterBagColumnsDefault;
        parent::find($request, $response);
    }

    public function saveSetor(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceSetor;
        $row = $request->getDataSet()->getRows()[0];
        if ($row["IDTIPOSETOR"] === "E") {
            $this->ParamKDSService->atualizarHabilitacao($row);
        }
        $this->parameterBagColumns = $this->parameterBagColumnsDefault;
        parent::save($request, $response);
    }

    public function saveTeclas(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceTeclas;
        $this->parameterBagColumns = $this->parameterBagColumnsDefault;
        parent::save($request, $response);
    }

    public function saveCores(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceCores;
        $this->parameterBagColumns = $this->parameterBagColumnsDefault;
        parent::save($request, $response);
    }

    public function saveLinhaProd(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceLinhaProducao;
        $this->parameterBagColumns = $this->parameterBagColumnsLinhaProd;
        $conditions = $this->utilService->getParamsAsArray($request);
        $Hundred = $this->ParamKDSService->somaLinhaPrincipal($conditions[0]["CDLINHAPROD"], $conditions[0]["CDFILIAL"]);
        $Hundred += $conditions[0]["NRPERCDEMANDA"];
        if($Hundred > 100){
            throw new \Exception("As somas das demandas não podem ser superior a 100%! ");
        }
        if($conditions[0]["IDLINHAPRINCIPAL"] == 'S') {
            $this->ParamKDSService->deleteLinhasetorprincipal($conditions[0]["CDFILIAL"]);
            $this->ParamKDSService->setLinhasetorprincipal($conditions[0]["CDLINHAPROD"], $conditions[0]["CDFILIAL"]);
            $this->ParamKDSService->setLinhaPrincipal($conditions[0]["CDLINHAPROD"], $conditions[0]["CDFILIAL"]);
        }
        parent::save($request, $response);
    }

    public function saveLinhaProdSetor(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceLinhaProducaoSetor;
        $this->parameterBagColumns = $this->parameterBagColumnsLinhaProdSetor;
        $conditions = $this->utilService->getParamsAsArray($request);
        $faltasetor = $this->ParamKDSService->getSetorprincipal($conditions[0]["CDFILIAL"]);
        if($conditions[0]["IDLINHAPRINCIPAL"] == 'S') {
            $this->ParamKDSService->setCorrespondente($conditions[0]["CDLINHAPROD"], $conditions[0]["CDFILIAL"], $conditions[0]["CDSETOR"]);
        }
        else if (empty($faltasetor)) {
            throw new \Exception("Não há setores cadastrados na linha principal. Cadastre um setor na linha principal!");
        }
        parent::save($request, $response);
    }

    public function saveOrdemMod(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceOrdem;
        $this->parameterBagColumns = $this->parameterBagColumnsOrdem;
        parent::save($request, $response);
    }

    public function saveFilial(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceFilial;
        $row = $request->getDataSet()->getRows()[0];
        if ($row["changed"]) {
            $this->ParamKDSService->updateUnidadeKDS($row);
        }
        return;
    }

    public function saveSetorFilial(DTO\Request $request, DTO\Response $response) {
        $newResponse = new DTO\Response;
        $rows = $request->getDataSet()->getRows();


        if(count($rows) === 1) {
            $row = $rows[0];
            $bool = $row->get('__is_new');

            $row->set('__is_new', true);

            if(!!$row['SOMBEEP'] && !is_string($row['SOMBEEP']) && count($row['SOMBEEP']) > 0 ) {
                foreach ($row['SOMBEEP'] as $file) {

                    $row->set('NMARQUIVO', $file['name']);
                    $row->set('TPARQUIVO', $file['type']);

                    // KDS uses only the base64.
                    // $metaData = $base64withMIMEDivided[0];
                    $base64withMIMEDivided = explode(",", $file['b64File']);
                    $base64 = $base64withMIMEDivided[1];
                    $row->set('ARQUIVO', $base64);

                    $row->set('CDARQUIVO', str_pad($this->novoCodigo->geraCodigo($this->conn, 'ARQUIVO'), 20, "0", STR_PAD_LEFT) );

                    $this->dataSourceName = self::dataSourceArquivos;
                    parent::save($request, $newResponse);
                }

                $this->fileUploaderService->setImageForSave($row, 'CDARQUIVO', 'SOMBEEP');
            }

            $row->set('__is_new', $bool);

            if (empty($row["CDARQUIVO"])) {
                $row["CDARQUIVO"] = "";
            }

            $this->dataSourceName = self::dataSourceSetorFilial;
            $this->parameterBagColumns = $this->parameterBagColumnsSetorLoja;
            parent::save($request, $response);
        }
    }

    public function saveSetorLoja(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceSetorLoja;
        $this->parameterBagColumns = $this->parameterBagColumnsDefault;
        $row = $request->getDataSet()->getRows()[0];

        $params = array(
			':CDFILIAL'     => $row['CDFILIAL'],
			':CDLOJA'    	=> $row['CDLOJA'],
			':CDSETOR'	    => $row['CDSETOR'],
			':IDTIPOSETOR'  => $row['IDTIPOSETOR']
		);

		$podeSalvar = $this->ParamKDSService->verificarProdutosSetor($params);

		if (gettype($podeSalvar) == 'boolean' && $podeSalvar) {
            parent::save($request, $response);
		}
        else
            $response->addDataSet(new DataSet("produtos_conflito", $podeSalvar));
    }

    public function saveProdutoSetor(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceProdutoSetor;
        $row = $request->getDataSet()->getRows()[0];

        $CDSETOR = $row['CDSETOR'];

        if(isset($row['NRTEMPOPROD']) || isset($row['NRTEMPOEXIB'])) {
            $row->set('NRTEMPOPROD', (((intval(substr($row['NRTEMPOPROD'], 0, 2))) * 60) + intval(substr($row['NRTEMPOPROD'], 3, 2))) . '');
            $row->set('NRTEMPOEXIB', (((intval(substr($row['NRTEMPOEXIB'], 0, 2))) * 60) + intval(substr($row['NRTEMPOEXIB'], 3, 2))) . '');
        }

        if($row['IDRESUMOPRODKDS'] == "DONTSHOW" || empty($row['IDRESUMOPRODKDS']))
            $row['IDRESUMOPRODKDS'] = null;

        if($row['IDRESTRICAOORIGEM'] == "NULL" || empty($row['IDRESTRICAOORIGEM']))
            $row['IDRESTRICAOORIGEM'] = null;

        $CDPRODUTO = $row['CDPRODUTO'];
        $CDARVPROD = $row['CDARVPROD'];
        $isNew  = $row['__is_new'];

        if (isset($row['CDPRODUTOFINAL'])) {
            $CDPRODUTOFINAL = $row['CDPRODUTOFINAL'];
            $CDARVPRODFINAL = $row['CDARVPRODFINAL'];
        } else {
            $CDPRODUTOFINAL = $row['CDPRODUTO'];
            $CDARVPRODFINAL = $row['CDARVPROD'];
        }

        if($isNew || ($CDARVPROD != $CDARVPRODFINAL))
            $prodArray = $this->ParamKDSService->GetProdInterval($CDARVPROD, $CDARVPRODFINAL, $CDSETOR, $isNew);
        else
            $prodArray = [array('CDPRODUTO' => $row['CDPRODUTO'])];

        foreach ($prodArray as $product) {
            $row['CDPRODUTO'] = $product['CDPRODUTO'];
            parent::save($request, $response);
        }
    }

    public function saveProdObsSetor(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceProdObsSetor;
        $row = $request->getDataSet()->getRows()[0];
        if($request->getDataSet()->getRows()[0]['__is_new'] == true){
            foreach ($request->getDataSet()->getRows()[0]['CDOCORR'] as $value) {
                $row['CDOCORR'] = $value;
                parent::save($request, $response);
            }
        }else{
            parent::save($request, $response);
        }
    }

    public function deleteTeclas(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceTeclas;
        parent::delete($request, $response);
    }

    public function deleteCores(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceCores;
        parent::delete($request, $response);
    }

    public function deleteSetor(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceSetor;
        parent::delete($request, $response);
    }
    public function verificarSetorFilial(DTO\Request $request, DTO\Response $response) {
        $row = $this->utilService->getParamsAsArray($request);
        if($this->ParamKDSService->totalSetoresPorLoja($row) !== 0){
            $response->addMessage(new Message("Esse setor está vinculado a uma ou mais lojas.", "E"));
        } elseif ($this->ParamKDSService->totalLinhaSetor($row) !== 0) {
            $response->addMessage(new Message("Esse setor está vinculado a uma ou mais linhas de produção.", "E"));
        } else {
            $this->deleteSetorFilial($request,$response);
        }
    }

    private function deleteSetorFilial (DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = self::dataSourceSetorFilial;
        parent::delete($request, $response);
    }

    public function deleteLinhaProd (DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = self::dataSourceLinhaProducao;
        $conditions = $this->utilService->getParamsAsArray($request);
        $this->ParamKDSService->deleteLinhasetor($conditions["CDLINHAPROD"], $conditions["CDFILIAL"]);
        parent::delete($request, $response);
    }

    public function deleteLinhaProdSetor (DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = self::dataSourceLinhaProducaoSetor;
        $conditions = $this->utilService->getParamsAsArray($request);
        $this->ParamKDSService->deleteSetorprincipal($conditions["CDSETOR"], $conditions["CDFILIAL"]);
        parent::delete($request, $response);
    }

    public function deleteOrdemMod (DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = self::dataSourceOrdem;
        parent::delete($request, $response);
    }

    public function deleteSetorLoja(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceSetorLoja;
        parent::delete($request, $response);
    }

    public function deleteProdutoSetor(DTO\Request\Row $request, DTO\Response $response) {
        $row = $this->utilService->getParamsAsArray($request);
        $this->ParamKDSService->deletarTodasObservacoesIntervalosProduto($this->conn, $row);
        $this->dataSourceName = self::dataSourceProdutoSetor;
        parent::delete($request, $response);
    }

    public function deleteMultiplo ($request, $response) {
        try {
            $dataSet = $request->getDataSet();

            $rows = $dataSet->getRows();

            foreach ($rows as $row) {
                $this->ParamKDSService->deletarTodasObservacoesIntervalosProduto($this->conn, $row);
            }

            $this->dataSourceName = self::dataSourceProdutoSetor;
            $dataSet->setDataSourceName($this->dataSourceName);
            $deletedRows = $this->dataSourceManager->delete($dataSet);
            $response->addDataSet(new DataSet($this->dataSourceName, $deletedRows));
            $nrDeletedRows = count($deletedRows);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }

    public function deleteProdObsSetor(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceProdObsSetor;
        parent::delete($request, $response);
    }

    public function editAutomatico (DTO\Request $request, DTO\Response $response) {
         $this->dataSourceName = self::dataSourceAltAutom;
         $row = $request->getDataSet()->getRows()[0];
         $nrProdutos = count($row['CDPRODUTO_BK']);

         for ($i = 0; $i < $nrProdutos; $i++) {
             $row['__is_new'] = false;
             $row['CDSETOR'] = $row['CDSETOR'];
             $row['CDPRODUTO'] = $row['CDPRODUTO_BK'][$i];
             $row['NRTEMPOPROD'] = $row['NRTEMPOPROD_BK'][$i];
             $row['NRTEMPOEXIB'] = $row['NRTEMPOEXIB_BK'][$i];
             $row['IDRESUMOPRODKDS'] = $row['IDRESUMOPRODKDS_BK'][$i];

             if($row['IDRESTRICAOORIGEM_BK'][$i] == 'NULL') {
                $row['IDRESTRICAOORIGEM'] = null;
             } else
                $row['IDRESTRICAOORIGEM'] = $row['IDRESTRICAOORIGEM_BK'][$i];

            if($row['IDRESUMOPRODKDS_BK'][$i] == 'DONTSHOW') {
                $row['IDRESUMOPRODKDS'] = null;
             } else
                $row['IDRESUMOPRODKDS'] = $row['IDRESUMOPRODKDS_BK'][$i];

             if($row['NRTEMPOPROD'] == 'NaN' || $row['NRTEMPOEXIB'] == 'NaN') {
                 $response->addMessage(new Message("Ocorreu um erro e a execucao da alteracao foi cancelada.", "E"));
                 break;
             } else {
                parent::save($request, $response);
             }
         }

        if($i != $nrProdutos)
            $response->addMessage(new Message("Nao foi possivel alterar todos os produtos. Produtos alterados:  $i", "E"));
    }

    public function deleteProdObsSetorMultiplo(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceProdObsSetor;
        parent::delete($request, $response);
    }

    public function findAlteracaoAut (DTO\Request $request, DTO\Response $response) {

    }

    public function editarProdutoTodosSetores (DTO\Request $request, DTO\Response $response) {
        $row = $this->utilService->getParamsAsArray($request);
        
        $backUpTempProd = $row['NRTEMPOPROD'];
        $backUpTempExib = $row['NRTEMPOEXIB'];

        $params = array(
            ':CDPRODUTO'    => $row['CDPRODUTO']
		);

		$setores = $this->ParamKDSService->getSetoresProducao($params);

        $method = "saveProdutoSetor";
        $routePath = $request->getRoutePath();
        $userId = $request->getUserId();

		foreach ($setores as $setor) {
            $row['CDSETOR'] = $setor['CDSETOR'];
            $row['NRTEMPOPROD'] = $backUpTempProd;
            $row['NRTEMPOEXIB'] = $backUpTempExib;
            $dataSet = new DataSet(self::dataSourceProdutoSetor, array($row));
		    $request = new DTO\Request\DataSet($dataSet, $method, $routePath, $userId);
		    $this->saveProdutoSetor($request, $response);
        }
    }

    public function importarProdutos (DTO\Request $request, DTO\Response $response) {
        $row = $this->utilService->getParamsAsArray($request);

	    $params = array(
            ':CDSETOR'      => $row['CDSETOR']
		);

		$cdsetor = $row['CDSETOR_DESTINO'];

        $arrayProdutos = array();
        $produtosResultQuery = $this->ParamKDSService->getProdutosSetor($params);

        $params[':CDSETOR'] = $row['CDSETOR_DESTINO'];
        $produtosJaExistentes = $this->ParamKDSService->getProdutosSetor($params);

        for ($i = 0; $i < sizeof($produtosJaExistentes); $i++) {
            array_push($arrayProdutos, $produtosJaExistentes[$i]['CDPRODUTO']);
        }

        $produtos = $produtosResultQuery;
        $qtdeProdutos = sizeof($produtos);

        for ($i = 0; $i < $qtdeProdutos; $i++) {

            $cdproduto = $produtos[$i]['CDPRODUTO'];

            if(!in_array($cdproduto, $arrayProdutos)) {
                $nrtempoprod = $produtos[$i]['NRTEMPOPROD'];
                $nrtempoexib = $produtos[$i]['NRTEMPOEXIB'];
                $idresumoprodkds = $produtos[$i]['IDRESUMOPRODKDS'];
                $idrestricaoorigem = $produtos[$i]['IDRESTRICAOORIGEM'];
                $dsapelidoresumo = $produtos[$i]['DSAPELIDORESUMO'];

                $params = array(
                    ':CDSETOR'            => $cdsetor,
        			':CDPRODUTO'          => $cdproduto,
        			':NRTEMPOPROD'        => $nrtempoprod,
        			':NRTEMPOEXIB'        => $nrtempoexib,
        			':IDRESUMOPRODKDS'    => $idresumoprodkds,
        			':IDRESTRICAOORIGEM'  => $idrestricaoorigem,
        			':DSAPELIDORESUMO'    => $dsapelidoresumo
    		    );

    		    $this->ParamKDSService->insertProdutoSetor($params);

    		    $params = array(
    		        ':CDSETOR'            => $row['CDSETOR'],
        	    	':CDPRODUTO'          => $cdproduto,
        	    	':CDSETOR_DESTINO'    =>$cdsetor
    		    );

    		    if($row['IMPORTAR_OBSERVACAO'] == 'S'){
    		        $this->insertObsProduto($params);
    		    }

    		    if($row['IMPORTAR_INTERVALO']=='S'){
    		        $this->insertIntervaloProduto($params, $row['NRORG']);
    		    }

            }

        }
        return $response;
    }
    private function insertIntervaloProduto($params){
        $intervalos = $this->ParamKDSService->getIntervalosProduto($params);
        foreach ($intervalos as $intervalo) {
            $intervalo['NRSEQINTERVALO'] = $this->novoCodigo->getCodeByTableName('SETORPRODINTER', $row['NRORG']);
            $intervalo['CDSETOR'] = $params[':CDSETOR_DESTINO'];
            $this->ParamKDSService->insertIntervaloProduto($intervalo);
        }
    }

    private function insertObsProduto($params){
        $obs = $this->ParamKDSService->getObservacaoProduto($params);
        foreach ($obs as $item) {
	        $item['CDSETOR'] = $params[':CDSETOR_DESTINO'];
            $this->ParamKDSService->insertObsProduto($item);
        }
    }

    public function importarSetor (DTO\Request\Row $request, DTO\Response $response){

        try{
            $rows = $this->utilService->getParamsAsArray($request);
            $numerosLinhas = $this->ParamKDSService->importarSetor($rows);
            $response->addDataSet(new DataSet('ImportarProdutoRepo', array('total'=>$numerosLinhas)));
        }catch(\Exception $e){
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
}